@@ -2,14 +2,15 @@ package Perinci::CmdLine::dux;
 use Moo;
 extends 'Perinci::CmdLine';
 
-our $VERSION = '1.26'; # VERSION
+our $VERSION = '1.27'; # VERSION
 
 sub run_subcommand {
     require Tie::Diamond;
 
     my $self = shift;
+    my $chomp = $self->{_meta}{"x.dux.strip_newlines"} // 1;
 
-    tie my(@diamond), 'Tie::Diamond', {chomp=>1} or die;
+    tie my(@diamond), 'Tie::Diamond', {chomp=>$chomp} or die;
     $self->{_args}{in}  = \@diamond;
     $self->{_args}{out} = [];
 
@@ -37,7 +38,7 @@ Perinci::CmdLine::dux - Perinci::CmdLine subclass for dux cli
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 AUTHOR
 
@@ -45,7 +46,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
